@@ -138,7 +138,9 @@ def main(argv=None):
         print('Sorry, I need rules file')
         return
 
-    outputfile = opt.outputfile or os.path.join(os.path.dirname(configfile), 'rules.pac')
+    CONFIG_PATH = os.path.dirname(os.path.abspath(configfile))
+
+    outputfile = opt.outputfile or os.path.join(CONFIG_PATH, 'rules.pac')
 
     cachefile = os.path.join('/tmp/networkInfoCache.pkl')
 
